@@ -10,7 +10,7 @@ use Clone qw/clone/;
 use Math::Symbolic qw/:all/;
 use Math::Symbolic::Custom::Pattern::Export;
 
-our $VERSION = '2.00';
+our $VERSION = '2.01';
 
 use constant EPSILON => 1e-29;
 
@@ -30,6 +30,7 @@ use constant NAMED_VAR   => 5;
 
 use constant ATTR_COMMUTATIVE => 1;
 
+=encoding utf8
 
 =head1 NAME
 
@@ -186,9 +187,9 @@ sub new {
   my %opt = @_;
 
   my $info = {
-    vars => {},
-    constants => {},
-    trees => {},
+    vars        => {},
+    constants   => {},
+    trees       => {},
     commutation => $opt{commutation},
   };
   
@@ -198,8 +199,8 @@ sub new {
 
   my $self = {
     pattern => $pattern,
-    info => $info,
-    string => $proto->to_string(),
+    info    => $info,
+    string  => $proto->to_string(),
   };
 
   return bless $self => $class;
@@ -473,7 +474,7 @@ sub _permute (&@) {
     my $q = $p or return;
     push @idx, reverse splice @idx, $p;
     ++$q while $idx[$p-1] > $idx[$q];
-    @idx[$p-1,$q]=@idx[$q,$p-1];
+    @idx[$p-1, $q] = @idx[$q, $p-1];
   }
 }
 
@@ -540,11 +541,11 @@ enhancing Math::Symbolic.
 
 =head1 AUTHOR
 
-Steffen Mller, E<lt>symbolic-module at steffen-mueller dot netE<gt>
+Steffen Mller, E<lt>smueller@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005-2008 by Steffen Mller
+Copyright (C) 2005, 2006, 2008, 2009, 2013 by Steffen Mueller
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.4 or,
